# Included Themes

Below is the documentation for the configuration and usage of all included themes.

## Acknowledgements & Licenses

A big thank you to the providers for themes that are used heavily throughout the project. Keep in mind any attributions made in the code are **required to keep in the code**.

[Start Bootstrap](https://startbootstrap.com/)

[HTML5UP](https://html5up.net/)

If you want to use an attribution free version of HTML5UP themes checkout [pixelarity](https://pixelarity.com/)

## Aerial

Author:  [HTML5Up](https://html5up.net/)

### Preview

Full page preview: [https://html5up.net/aerial](https://html5up.net/aerial)

<img src="/en/latest/img/theme-previews/aerial.png" width="100%" height="500px">



### Usage

To use this theme in your code either initialize the project with "aerial" as the theme, or set it in your ```config.yml``` file:

```yaml
... # Other configuration settings
theme: aerial
... # Other configuration settings
```

**Notes**

Tips from the theme developer about the scrolling background:

> You can still use pretty much any image you want, but for best results make sure yours is: 
> 
> - Horizontally tileable
> - Wide and short 
> - About 1500px wide
> - Fades to a solid color either at the top of bottom (which is used to fill the empty space above or below your image).
> - The example image is [here](https://www.flickr.com/photos/ryanschroeder/11876741703)

#### Supported config settings

The following settings are supported and not supported in the ```config.yml``` file:

✅: Required

☑️: Optional

❌: Not Supported

```
name: ✅
background: ☑️
avatar: ❌
email: ☑️
phone: ☑️
biography: ❌
role: ☑️ (recommended)
company: ☑️ (recommended)
address: ❌
social: ☑️
  github: ☑️
  twitch: ☑️
  youtube: ☑️
  instagram: ☑️
  twitter: ☑️
  snapchat: ☑️
  linkedin: ☑️
  facebook: ☑️
```
#### Supported Sections

Below are a list of the supported, and unsupported sections.

✔️: Supported

❌: Not Supported

```yml
Projects: ❌
Education: ❌
Work Experience: ❌
Volunteering Experience: ❌
Gallery: ❌
Blog: ❌
```

## Creative

Author:  [Start Bootstrap](https://startbootstrap.com)

Theme page: [https://startbootstrap.com/theme/creative](https://startbootstrap.com/theme/creative)

### Preview

Full page preview: [https://startbootstrap.com/previews/creative](https://startbootstrap.com/previews/creative)

<iframe src="https://startbootstrap.github.io/startbootstrap-creative/" width="100%" height="500px">
</iframe>

### Usage

To use this theme in your code either initialize the project with "creative" as the theme, or set it in your ```config.yml``` file:

```yaml
... # Other configuration settings
theme: creative
... # Other configuration settings
```

**Notes**

For images in projects the dimensions are (530px x 450px)

#### Supported config settings

The following settings are supported and not supported in the ```config.yml``` file:

✅: Required

☑️: Optional

❌: Not Supported

```
name: ✅
background: ☑️ (recommended)
avatar: ❌
email: ☑️
phone: ☑️
biography: ☑️ (recommended)
role: ☑️ (recommended)
company: ☑️ (recommended)
address: ☑️
social: ❌
  github: ❌
  twitch: ❌
  youtube: ❌
  instagram: ❌
  twitter: ❌
  snapchat: ❌
  linkedin: ❌
  facebook: ❌
```
#### Supported Sections

Below are a list of the supported, and unsupported sections.

✔️: Supported

❌: Not Supported

```yml
Projects: ✔️
Education: ❌
Work Experience: ❌
Volunteering Experience: ❌
Gallery: ✔️
Blog: ❌
```

## cv

Author:  [Start Bootstrap](https://startbootstrap.com)

Theme page: [https://startbootstrap.com/theme/resume](https://startbootstrap.com/theme/resume)

### Preview

Full page preview: [https://startbootstrap.com/previews/resume](https://startbootstrap.com/previews/resume)

<iframe src="https://startbootstrap.github.io/startbootstrap-resume/" width="100%" height="500px">
</iframe>


### Usage

To use this theme in your code either initialize the project with "cv" as the theme, or set it in your ```config.yml``` file:

```yaml
... # Other configuration settings
theme: cv
... # Other configuration settings
```

**Notes**
For the avatar image use a 1:1 ratio (square image), and ideally around ~500x500

#### Supported config settings

The following settings are supported and not supported in the ```config.yml``` file:

✅: Required

☑️: Optional

❌: Not Supported

```
name: ✅
background: ❌
avatar: ☑️ (HIGHLY recommended)
email: ☑️ (recommended)
phone: ☑️ (recommended)
biography: ☑️ (recommended)
role: ☑️ (recommended)
company: ☑️ (recommended)
address: ☑️
social: ☑️
  github: ☑️
  twitch: ☑️
  youtube: ☑️
  instagram: ☑️
  twitter: ☑️
  snapchat: ☑️
  linkedin: ☑️
  facebook: ☑️
```

#### Supported Sections

Below are a list of the supported, and unsupported sections.

✔️: Supported

❌: Not Supported

```yml
Projects: ✔️
Education: ✔️
Work Experience: ✔️
Volunteering Experience: ✔️
Gallery: ❌
Blog: ❌
```

## Dimension

Author:  [HTML5Up](https://html5up.net)

### Preview

Full page preview: [https://html5up.net/dimension](https://html5up.net/dimension)

<img src="/en/latest/img/theme-previews/dimension.jpg" width="100%" height="500px">


### Usage

To use this theme in your code either initialize the project with "dimension" as the theme, or set it in your ```config.yml``` file:

```yaml
... # Other configuration settings
theme: dimension
... # Other configuration settings
```

#### Supported config settings

The following settings are supported and not supported in the ```config.yml``` file:

✅: Required

☑️: Optional

❌: Not Supported

```
name: ✅
background: ☑️ (recommended)
avatar: ☑️
email: ☑️
phone: ☑️
biography: ✅
role: ☑️ (recommended)
company: ☑️ (recommended)
address: ☑️
social: ☑️
  github: ☑️
  twitch: ☑️
  youtube: ☑️
  instagram: ☑️
  twitter: ☑️
  snapchat: ☑️
  linkedin: ☑️
  facebook: ☑️
```
#### Supported Sections

Below are a list of the supported, and unsupported sections.

✔️: Supported

❌: Not Supported

```yml
Projects: ✔️
Education: ✔️
Work Experience: ✔️
Volunteering Experience: ✔️
Gallery: ✔️
Blog: ✔️
```

## Ethereal

Author:  [HTML5Up](https://html5up.net)

### Preview

Full page preview: [https://html5up.net/ethereal](https://html5up.net/ethereal)

<img src="/en/latest/img/theme-previews/ethereal.jpg" width="100%" height="500px">


### Usage

To use this theme in your code either initialize the project with "ethereal" as the theme, or set it in your ```config.yml``` file:

```yaml
... # Other configuration settings
theme: ethereal
... # Other configuration settings
```

**Notes**

For best usage the avatar should be (525px x 900px)

**With the gallery the design will be different if you have a set of images that are divisible by either 2, 3, or 4**

#### Supported config settings

The following settings are supported and not supported in the ```config.yml``` file:

✅: Required

☑️: Optional

❌: Not Supported

```
name: ✅
background: ❌
avatar: ✅
email: ☑️
phone: ☑️
biography: ✅
role: ☑️ (recommended)
company: ☑️ (recommended)
address: ❌
social: ☑️
  github: ☑️
  twitch: ☑️
  youtube: ☑️
  instagram: ☑️
  twitter: ☑️
  snapchat: ☑️
  linkedin: ☑️
  facebook: ☑️
```
#### Supported Sections

Below are a list of the supported, and unsupported sections.

✔️: Supported

❌: Not Supported

```yml
Projects: ❌
Education: ✔️
Work Experience: ✔️
Volunteering Experience: ✔️
Gallery: ✔️
Blog: ❌
```

## Freelancer

Author:  [Start Bootstrap](https://startbootstrap.com)

Theme page: [https://startbootstrap.com/theme/freelancer](https://startbootstrap.com/theme/freelancer)


### Preview

Full page preview: [https://startbootstrap.com/previews/freelancer](https://startbootstrap.com/previews/freelancer)

<iframe src="https://startbootstrap.github.io/startbootstrap-freelancer/" width="100%" height="500px">
</iframe>

### Usage

To use this theme in your code either initialize the project with "freelancer" as the theme, or set it in your ```config.yml``` file:

```yaml
... # Other configuration settings
theme: freelancer
... # Other configuration settings
```

#### Supported config settings

The following settings are supported and not supported in the ```config.yml``` file:

✅: Required

☑️: Optional

❌: Not Supported

```
name: ✅
background: ❌
avatar: ☑️ (recommended)
email: ☑️
phone: ☑️
biography: ☑️ (recommended)
role: ☑️ (recommended)
company: ☑️ (recommended)
address: ☑️
social: ☑️
  github: ☑️
  twitch: ☑️
  youtube: ☑️
  instagram: ☑️
  twitter: ☑️
  snapchat: ☑️
  linkedin: ☑️
  facebook: ☑️
```
#### Supported Sections

Below are a list of the supported, and unsupported sections.

✔️: Supported

❌: Not Supported

```yml
Projects: ✔️
Education: ✔️
Work Experience: ✔️
Volunteering Experience: ✔️
Gallery: ❌
Blog: ❌
```

## Grayscale

Author:  [Start Bootstrap](https://startbootstrap.com)

Theme page: [https://startbootstrap.com/theme/grayscale](https://startbootstrap.com/theme/grayscale)

### Preview

Full page preview: [https://startbootstrap.com/previews/grayscale](https://startbootstrap.com/previews/grayscale)

<iframe src="https://startbootstrap.github.io/startbootstrap-grayscale/" width="100%" height="500px">
</iframe>


### Usage

To use this theme in your code either initialize the project with "grayscale" as the theme, or set it in your ```config.yml``` file:

```yaml
... # Other configuration settings
theme: grayscale
... # Other configuration settings
```

**Notes**
It is recommended to make images ~ 600px x 440px for projects

#### Supported config settings

The following settings are supported and not supported in the ```config.yml``` file:

✅: Required

☑️: Optional

❌: Not Supported

```
name: ✅
background: ☑️ (recommended)
avatar: ❌
email: ☑️
phone: ☑️
biography: ☑️ (recommended)
role: ☑️ (recommended)
company: ☑️ (recommended)
address: ☑️
social: ☑️
  github: ☑️
  twitch: ☑️
  youtube: ☑️
  instagram: ☑️
  twitter: ☑️
  snapchat: ☑️
  linkedin: ☑️
  facebook: ☑️
```

#### Supported Sections

Below are a list of the supported, and unsupported sections.

✔️: Supported

❌: Not Supported

```yml
Projects: ✔️
Education: ✔️
Work Experience: ✔️
Volunteering Experience: ✔️
Gallery: ❌
Blog: ✔️
```

## Identity

Author:  [HTML5Up](https://html5up.net/)

### Preview

Full page preview: [https://html5up.net/identity](https://html5up.net/identity)

<img src="/en/latest/img/theme-previews/identity.png" width="100%" height="500px">



### Usage

To use this theme in your code either initialize the project with "identity" as the theme, or set it in your ```config.yml``` file:

```yaml
... # Other configuration settings
theme: identity
... # Other configuration settings
```

#### Supported config settings

The following settings are supported and not supported in the ```config.yml``` file:

✅: Required

☑️: Optional

❌: Not Supported

```
name: ✅
background: ☑️
avatar: ✅
email: ☑️
phone: ☑️
biography: ❌
role: ☑️ 
company: ☑️
address: ❌
social: ☑️
  github: ☑️
  twitch: ☑️
  youtube: ☑️
  instagram: ☑️
  twitter: ☑️
  snapchat: ☑️
  linkedin: ☑️
  facebook: ☑️
```
#### Supported Sections

Below are a list of the supported, and unsupported sections.

✔️: Supported

❌: Not Supported

```yml
Projects: ❌
Education: ❌
Work Experience: ❌
Volunteering Experience: ❌
Gallery: ❌
Blog: ❌
```

## Lens

Author:  [HTML5Up](https://html5up.net)

### Preview

Full page preview: [https://html5up.net/lens](https://html5up.net/lens)

<img src="/en/latest/img/theme-previews/lens.jpg" width="100%" height="500px">



### Usage

To use this theme in your code either initialize the project with "strata" as the theme, or set it in your ```config.yml``` file:

```yaml
... # Other configuration settings
theme: lens
... # Other configuration settings
```

#### Supported config settings

The following settings are supported and not supported in the ```config.yml``` file:

✅: Required

☑️: Optional

❌: Not Supported

```
name: ✅
background: ❌
avatar: ☑️
email: ☑️
phone: ☑️
biography: ✅
role: ☑️
company: ☑️
address: ❌
social: ☑️
  github: ☑️
  twitch: ☑️
  youtube: ☑️
  instagram: ☑️
  twitter: ☑️
  snapchat: ☑️
  linkedin: ☑️
  facebook: ☑️
```

#### Supported Sections

Below are a list of the supported, and unsupported sections.

✔️: Supported

❌: Not Supported

```yml
Projects: ❌
Education: ❌
Work Experience: ❌
Volunteering Experience: ❌
Gallery: ✔️
Blog: ❌
```

## Paradigm Shift

Author:  [HTML5Up](https://html5up.net/)

### Preview

Full page preview: [https://html5up.net/paradigm-shift](https://html5up.net/paradigm-shift)

<img src="/en/latest/img/theme-previews/paradigm_shift.png" width="100%" height="500px">




### Usage

To use this theme in your code either initialize the project with "identity" as the theme, or set it in your ```config.yml``` file:

```yaml
... # Other configuration settings
theme: paradigm_shift
... # Other configuration settings
```

**Notes**

This theme supports an extra config variable called `fancy_gallery` which can be set to `true` in order to force all gallery photos to be in landscape mode instead of switching between landscape and portrait. It would be used like this:



```yaml
...# Other settings
disable_fancy_gallery: true
...# Other settings
```



The `background` and `avatar` settings will both be used in the same location for the same thing and are interchangeable. If both are provided then only the value from the `avatar` config variable is used. Dimensions should be as close to 1350x1110 pixels as possible.



#### Supported config settings

The following settings are supported and not supported in the ```config.yml``` file:

✅: Required

☑️: Optional

❌: Not Supported

```
name: ✅
background: ✅ (Can use either avatar or background, but need to fill in one or the other. See notes for details)
avatar: ✅ (Can use either avatar or background, but need to fill in one or the other. See notes for details)
email: ☑️
phone: ☑️
biography: ☑️
role: ☑️ 
company: ☑️
address: ❌
social: ☑️
  github: ☑️
  twitch: ☑️
  youtube: ☑️
  instagram: ☑️
  twitter: ☑️
  snapchat: ☑️
  linkedin: ☑️
  facebook: ☑️
```

#### Supported Sections

Below are a list of the supported, and unsupported sections.

✔️: Supported

❌: Not Supported

```yml
Projects: ✔️
Education: ✔️
Work Experience: ✔️
Volunteering Experience: ✔️
Gallery: ✔️
Blog: ❌
```

## Read Only

Author:  [HTML5Up](https://html5up.net/)

### Preview

Full page preview: [https://html5up.net/read-only](https://html5up.net/read-only)

<img src="/en/latest/img/theme-previews/read_only.png" width="100%" height="500px">


### Usage

To use this theme in your code either initialize the project with "read_only" as the theme, or set it in your ```config.yml``` file:

```yaml
... # Other configuration settings
theme: read_only
... # Other configuration settings
```

**Notes**

For images in projects the dimensions are (400px x 235px)

#### Supported config settings

The following settings are supported and not supported in the ```config.yml``` file:

✅: Required

☑️: Optional

❌: Not Supported

```
name: ✅
background: ✅
avatar: ✅
email: ☑️
phone: ☑️
biography: ✅
role: ☑️ 
company: ☑️
address: ❌
social: ☑️
  github: ☑️
  twitch: ☑️
  youtube: ☑️
  instagram: ☑️
  twitter: ☑️
  snapchat: ☑️
  linkedin: ☑️
  facebook: ☑️
```
#### Supported Sections

Below are a list of the supported, and unsupported sections.

✔️: Supported

❌: Not Supported

```yml
Projects: ✔️
Education: ✔️
Work Experience: ✔️
Volunteering Experience: ✔️
Gallery: ❌
Blog: ✔️
```


## Solid State

Author:  [HTML5Up](https://html5up.net/)

### Preview

Full page preview: [https://html5up.net/solid-state](https://html5up.net/solid-state)

<img src="/en/latest/img/theme-previews/solid_state.png" width="100%" height="500px">


### Usage

To use this theme in your code either initialize the project with "solid_state" as the theme, or set it in your ```config.yml``` file:

```yaml
... # Other configuration settings
theme: solid_state
... # Other configuration settings
```

**Notes**

For images in projects the dimensions are square (i.e. 500px x 500px)

#### Supported config settings

The following settings are supported and not supported in the ```config.yml``` file:

✅: Required

☑️: Optional

❌: Not Supported

```
name: ✅
background: ❌
avatar: ❌
email: ☑️
phone: ☑️
biography: ✅
role: ☑️ 
company: ☑️
address: ❌
social: ☑️
  github: ☑️
  twitch: ☑️
  youtube: ☑️
  instagram: ☑️
  twitter: ☑️
  snapchat: ☑️
  linkedin: ☑️
  facebook: ☑️
```
#### Supported Sections

Below are a list of the supported, and unsupported sections.

✔️: Supported

❌: Not Supported

```yml
Projects: ✔️
Education: ✔️
Work Experience: ✔️
Volunteering Experience: ✔️
Gallery: ❌
Blog: ✔️
```

## Strata

Author:  [HTML5Up](https://html5up.net)

### Preview

Full page preview: [https://html5up.net/strata](https://html5up.net/strata)

<img src="/en/latest/img/theme-previews/strata.png" width="100%" height="500px">

### Usage

To use this theme in your code either initialize the project with "strata" as the theme, or set it in your ```config.yml``` file:

```yaml
... # Other configuration settings
theme: strata
... # Other configuration settings
```

#### Supported config settings

The following settings are supported and not supported in the ```config.yml``` file:

✅: Required

☑️: Optional

❌: Not Supported

```
name: ✅
background: ☑️
avatar: ✅
email: ☑️
phone: ☑️
biography: ✅
role: ☑️
company: ☑️
address: ❌
social: ☑️
  github: ☑️
  twitch: ☑️
  youtube: ☑️
  instagram: ☑️
  twitter: ☑️
  snapchat: ☑️
  linkedin: ☑️
  facebook: ☑️
```
#### Supported Sections

Below are a list of the supported, and unsupported sections.

✔️: Supported

❌: Not Supported

```yml
Projects: ✔️
Education: ✔️
Work Experience: ✔️
Volunteering Experience: ✔️
Gallery: ✔️
Blog: ❌
```
